#[non_exhaustive]pub enum MetadataPointers {
Enabled,
Disabled,
}Expand description
Whether the metadata section may use data-section pointers.
Pointers make the metadata marginally smaller by sharing repeated strings, but a few historic readers mishandle them. Disable to emit fully inline metadata.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Enabled
Allow pointers in the metadata section. Default.
Disabled
Emit metadata without any pointers.